//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[Shanten](index.md)

# Shanten

@Serializable

interface [Shanten](index.md)

向听信息

#### Inheritors

| |
|---|
| [CommonShanten](../-common-shanten/index.md) |
| [ShantenWithFuroChance](../-shanten-with-furo-chance/index.md) |

## Properties

| Name | Summary |
|---|---|
| [shantenNum](shanten-num.md) | [common]<br>abstract val [shantenNum](shanten-num.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)<br>向听数 |
